{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/bio-client:latest"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 2000,
                    "ramMax": 2000,
                    "tmpdirMin": "$(Math.ceil (inputs.file_size / 1048576))",
                    "tmpdirMax": "$(Math.ceil (inputs.file_size / 1048576))",
                    "outdirMin": "$(Math.ceil (inputs.file_size / 1048576))",
                    "outdirMax": "$(Math.ceil (inputs.file_size / 1048576))"
                }
            ],
            "inputs": [
                {
                    "id": "#bio_client_download.cwl/config-file",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c",
                        "position": 0
                    }
                },
                {
                    "id": "#bio_client_download.cwl/dir_path",
                    "type": "string",
                    "default": ".",
                    "inputBinding": {
                        "prefix": "--dir_path",
                        "position": 99
                    }
                },
                {
                    "id": "#bio_client_download.cwl/download",
                    "type": "string",
                    "default": "download",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#bio_client_download.cwl/download_handle",
                    "type": "string",
                    "inputBinding": {
                        "position": 98
                    }
                },
                {
                    "id": "#bio_client_download.cwl/file_size",
                    "type": "long",
                    "default": 1
                }
            ],
            "baseCommand": [
                "/usr/local/bin/bio_client.py"
            ],
            "id": "#bio_client_download.cwl",
            "outputs": [
                {
                    "id": "#bio_client_download.cwl/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    }
                }
            ]
        },
        {
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#amplicon_kit.yml/amplicon_kit_set_file",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#amplicon_kit.yml/amplicon_kit_set_file/amplicon_kit_amplicon_file",
                                    "type": "File"
                                },
                                {
                                    "name": "#amplicon_kit.yml/amplicon_kit_set_file/amplicon_kit_target_file",
                                    "type": "File"
                                }
                            ]
                        },
                        {
                            "name": "#amplicon_kit.yml/amplicon_kit_set_uuid",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#amplicon_kit.yml/amplicon_kit_set_uuid/amplicon_kit_amplicon_uuid",
                                    "type": "string"
                                },
                                {
                                    "name": "#amplicon_kit.yml/amplicon_kit_set_uuid/amplicon_kit_amplicon_file_size",
                                    "type": "long"
                                },
                                {
                                    "name": "#amplicon_kit.yml/amplicon_kit_set_uuid/amplicon_kit_target_uuid",
                                    "type": "string"
                                },
                                {
                                    "name": "#amplicon_kit.yml/amplicon_kit_set_uuid/amplicon_kit_target_file_size",
                                    "type": "long"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "class": "ExpressionTool",
            "inputs": [
                {
                    "id": "#emit_amplicon_kit_file.cwl/amplicon_kit_amplicon_file",
                    "type": "File"
                },
                {
                    "id": "#emit_amplicon_kit_file.cwl/amplicon_kit_target_file",
                    "type": "File"
                }
            ],
            "outputs": [
                {
                    "id": "#emit_amplicon_kit_file.cwl/output",
                    "type": "#amplicon_kit.yml/amplicon_kit_set_file"
                }
            ],
            "expression": "${\n  var output = {'amplicon_kit_amplicon_file': inputs.amplicon_kit_amplicon_file,\n                'amplicon_kit_target_file': inputs.amplicon_kit_target_file};\n  return {'output': output};\n}\n",
            "id": "#emit_amplicon_kit_file.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#amplicon_kit.yml/amplicon_kit_set_file"
                        },
                        {
                            "$import": "#amplicon_kit.yml/amplicon_kit_set_uuid"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#main/bioclient_config",
                    "type": "File"
                },
                {
                    "id": "#main/amplicon_kit_set_uuid",
                    "type": "#amplicon_kit.yml/amplicon_kit_set_uuid"
                }
            ],
            "outputs": [
                {
                    "id": "#main/output",
                    "type": "#amplicon_kit.yml/amplicon_kit_set_file",
                    "outputSource": "#main/emit_amplicon_kit/output"
                }
            ],
            "steps": [
                {
                    "id": "#main/extract_amplicon_kit_amplicon",
                    "run": "#bio_client_download.cwl",
                    "in": [
                        {
                            "id": "#main/extract_amplicon_kit_amplicon/config-file",
                            "source": "#main/bioclient_config"
                        },
                        {
                            "id": "#main/extract_amplicon_kit_amplicon/download_handle",
                            "source": "#main/amplicon_kit_set_uuid",
                            "valueFrom": "$(self.amplicon_kit_amplicon_uuid)"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/extract_amplicon_kit_amplicon/output"
                        }
                    ]
                },
                {
                    "id": "#main/extract_amplicon_kit_target",
                    "run": "#bio_client_download.cwl",
                    "in": [
                        {
                            "id": "#main/extract_amplicon_kit_target/config-file",
                            "source": "#main/bioclient_config"
                        },
                        {
                            "id": "#main/extract_amplicon_kit_target/download_handle",
                            "source": "#main/amplicon_kit_set_uuid",
                            "valueFrom": "$(self.amplicon_kit_target_uuid)"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/extract_amplicon_kit_target/output"
                        }
                    ]
                },
                {
                    "id": "#main/emit_amplicon_kit",
                    "run": "#emit_amplicon_kit_file.cwl",
                    "in": [
                        {
                            "id": "#main/emit_amplicon_kit/amplicon_kit_amplicon_file",
                            "source": "#main/extract_amplicon_kit_amplicon/output"
                        },
                        {
                            "id": "#main/emit_amplicon_kit/amplicon_kit_target_file",
                            "source": "#main/extract_amplicon_kit_target/output"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/emit_amplicon_kit/output"
                        }
                    ]
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
